@@ -37,7 +37,7 @@ class StorageBackend(RemoteStorageBackendMixin, BaseStorageBackend): # pylint: d
             handler.fd.seek(0)
             blob = self.get_blob_client(handler.path)
             with open(handler.fd.name, 'rb') as f:
-                blob.upload_blob(f)
+                blob.upload_blob(f, overwrite=True)
 
     def download(self, path, dst):
         """Downloads file from `path` to `dst` on the local filesystem."""
@@ -80,7 +80,7 @@ class StorageBackend(RemoteStorageBackendMixin, BaseStorageBackend): # pylint: d
         """Copies local absolute path `src` to remote `path`."""
         blob = self.get_blob_client(path)
         with open(src, 'rb') as f:
-            blob.upload_blob(f)
+            blob.upload_blob(f, overwrite=True)
 
     def unlink(self, path):
         """Remove a path."""
