@@ -3,6 +3,8 @@ import abc
 import os
 import tempfile
 
+from aiofile import AIOFile
+
 from ..asyncdescriptor import AsyncDescriptor
 from ..descriptor import Descriptor
 
@@ -36,7 +38,7 @@ class BaseStorageBackend(metaclass=abc.ABCMeta):
 
         This method has no effect if the file is already closed.
         """
-        raise NotImplementedError("Subclasses must override this method.")
+        await handler.fd.__aexit__()
 
     async def async_download(self, path, dst):
         """Downloads file from `path` to `dst` on the local filesystem."""
@@ -46,6 +48,16 @@ class BaseStorageBackend(metaclass=abc.ABCMeta):
         """Copies local absolute path `src` to remote `path`."""
         raise NotImplementedError("Subclasses must override this method.")
 
+    async def async_exists(self, path):
+        """Test whether a path exists.  Returns False for broken symbolic links
+        if the storage backend supports them.
+        """
+        raise NotImplementedError("Subclasses must override this method.")
+
+    def async_open(self, path, mode='rt', *args, **kwargs): # pylint: disable=W1113
+        """Open the given `path` in the given `mode`."""
+        return self.async_descriptor_class(self, path, mode, *args, **kwargs)
+
     async def async_pull(self, path, dst=None):
         """Pulls a file from the given `path` in the storage backend to local
         filepath `dst`. If `dst` is ``None``, then a temporary filepath is
@@ -76,12 +88,6 @@ class BaseStorageBackend(metaclass=abc.ABCMeta):
         """
         raise NotImplementedError("Subclasses must override this method.")
 
-    async def async_exists(self, path):
-        """Test whether a path exists.  Returns False for broken symbolic links
-        if the storage backend supports them.
-        """
-        raise NotImplementedError("Subclasses must override this method.")
-
     def get_local_fd(self, handler):
         """Opens a local file descriptor."""
         raise NotImplementedError("Subclasses must override this method.")
@@ -107,10 +113,6 @@ class BaseStorageBackend(metaclass=abc.ABCMeta):
             raise FileNotFoundError("No such file or directory: '%s'" % path)
         return self.descriptor_class(self, path, mode, *args, **kwargs)
 
-    def async_open(self, path, mode='rt', *args, **kwargs): # pylint: disable=W1113
-        """Open the given `path` in the given `mode`."""
-        return self.async_descriptor_class(self, path, mode, *args, **kwargs)
-
     def read(self, handler, size=-1):
         """Read at most n characters from handler.
 
@@ -145,4 +147,6 @@ class RemoteStorageBackendMixin: # pylint: disable=R0903
     def get_local_fd(self, handler): # pylint: disable=R0201
         """Opens a local file descriptor."""
         _, src = tempfile.mkstemp()
-        return open(src, handler.mode)
+        return open(src, handler.mode)\
+            if not handler.is_async()\
+            else AIOFile(src, handler.mode)
