@@ -13,13 +13,6 @@ class LocalDiskBackend(BaseStorageBackend):
     """A storage backend that uses the local filesystem."""
     kind = 'local'
 
-    async def async_close(self, handler):
-        """Flush and close the IO object.
-
-        This method has no effect if the file is already closed.
-        """
-        await handler.fd.__aexit__()
-
     async def async_download(self, path, dst):
         """This method exists only for API compatibility."""
         src = self.storage_path(path)
